.:GetBlogName:.

.:GetStyleSheets:.
.:IfInfiniteScrollEnabled:: .:IfInThread::
:: :.
:. .:ForBlogMetadataIfExists::custom_scripts::
:. .:ForBlogMetadataIfExists::custom_styles:::.
.:IfCategories::

CATEGORIES

.:IfBlogMetadataIsTrue::disable_blog_hashtags:: ::

.:GetFlattenedBlogCategories::
- #{value}
:: :.

:. .:IfBlogMetadataIsTrue::disable_categories_tree:: ::

.:GetBlogCategoriesTree::

::
- {value}::{childs}
::

:.
:.
:. .:IfChapters::

CHAPTERS

.:IfBlogMetadataIsTrue::disable_chapters:: ::

.:GetChapters::

::
- {index}. {title}::
::

:.
:.
:.